==> libtangle_0.0.20100221.tar.gz: libtangle-0.0.20100221/tangle/tangle-button.h <==
/*
 * tangle-button.h
 *
 * This file is part of Tangle Toolkit - A graphical widget library based on Clutter Toolkit
 *
 * (c) 2009-2010 Henrik Hedberg <henrik.hedberg@innologies.fi>
 *
 */

#ifndef __TANGLE_BUTTON_H__
#define __TANGLE_BUTTON_H__

#include <clutter/clutter.h>
#include "tangle-widget.h"
#include "tangle-action.h"

#define TANGLE_TYPE_BUTTON (tangle_button_get_type ())
#define TANGLE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TANGLE_TYPE_BUTTON, TangleButton))
#define TANGLE_IS_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TANGLE_TYPE_BUTTON))
#define TANGLE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TANGLE_BUTTON, TangleButtonClass))
#define TANGLE_IS_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TANGLE_TYPE_BUTTON))
#define TANGLE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TANGLE_TYPE_BUTTON, TangleButtonClass))

typedef struct _TangleButtonPrivate TangleButtonPrivate;

typedef struct _TangleButton {
	TangleWidget parent_instance;

	TangleButtonPrivate* priv;
} TangleButton;

typedef struct _TangleButtonClass {
	TangleWidgetClass parent_class;
	
	gboolean (*clicked)(TangleButton* button);
} TangleButtonClass;

GType tangle_button_get_type(void) G_GNUC_CONST;


ClutterActor* tangle_button_new(void);
ClutterActor* tangle_button_new_with_background_actor(ClutterActor* normal_background_actor);
ClutterActor* tangle_button_new_with_background_actors(ClutterActor* normal_background_actor, ClutterActor* interactive_background_actor);
ClutterActor* tangle_button_get_normal_background_actor(TangleButton* button);
ClutterActor* tangle_button_get_interactive_background_actor(TangleButton* button);
TangleAction* tangle_button_get_clicked_action(TangleButton* button);
void tangle_button_set_normal_background_actor(TangleButton* button, ClutterActor* actor);
void tangle_button_set_interactive_background_actor(TangleButton* button, ClutterActor* actor);
void tangle_button_set_clicked_action(TangleButton* button, TangleAction* action);

#endif

==> libtangle_0.0.20100307.tar.gz: libtangle-0.0.20100307/tangle/tangle-button.h <==
/*
 * tangle-button.h
 *
 * This file is part of Tangle Toolkit - A graphical widget library based on Clutter Toolkit
 *
 * (c) 2009-2010 Henrik Hedberg <henrik.hedberg@innologies.fi>
 *
 */

#ifndef __TANGLE_BUTTON_H__
#define __TANGLE_BUTTON_H__

#include <clutter/clutter.h>
#include "tangle-widget.h"
#include "tangle-action.h"

#define TANGLE_TYPE_BUTTON (tangle_button_get_type ())
#define TANGLE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TANGLE_TYPE_BUTTON, TangleButton))
#define TANGLE_IS_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TANGLE_TYPE_BUTTON))
#define TANGLE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TANGLE_TYPE_BUTTON, TangleButtonClass))
#define TANGLE_IS_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TANGLE_TYPE_BUTTON))
#define TANGLE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TANGLE_TYPE_BUTTON, TangleButtonClass))

typedef struct _TangleButtonPrivate TangleButtonPrivate;

typedef struct _TangleButton {
	TangleWidget parent_instance;

	TangleButtonPrivate* priv;
} TangleButton;

typedef struct _TangleButtonClass {
	TangleWidgetClass parent_class;
	
	gboolean (*clicked)(TangleButton* button);
} TangleButtonClass;

GType tangle_button_get_type(void) G_GNUC_CONST;


ClutterActor* tangle_button_new(void);
ClutterActor* tangle_button_new_with_background_actor(ClutterActor* normal_background_actor);
ClutterActor* tangle_button_new_with_background_actors(ClutterActor* normal_background_actor, ClutterActor* interactive_background_actor);
ClutterActor* tangle_button_get_normal_background_actor(TangleButton* button);
ClutterActor* tangle_button_get_interactive_background_actor(TangleButton* button);
TangleAction* tangle_button_get_clicked_action(TangleButton* button);
void tangle_button_set_normal_background_actor(TangleButton* button, ClutterActor* actor);
void tangle_button_set_interactive_background_actor(TangleButton* button, ClutterActor* actor);
void tangle_button_set_clicked_action(TangleButton* button, TangleAction* action);

#endif
